/**
 * University of Illinois/NCSA Open Source License
 *
 * Copyright (c) 2011 Milos Gligoric
 * All rights reserved.
 *
 * Developed by:  Milos Gligoric <milos.gligoric@gmail.edu>
 *                University of Illinois at Urbana-Champaign
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimers.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimers in the
 *    documentation and/or other materials provided with the distribution.
 *  * Neither the names of Milos Gligoric, University of Illinois at Urbana-
 *    Champaign, nor the names of its contributors may be used to endorse
 *    or promote products derived from this Software without specific prior
 *    written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package codese.extend;

import java.io.IOException;

public class ASideValues {

  private int booleanIx;
  private int byteIx;
  private int shortIx;
  private int charIx;
  private int intIx;
  private int longIx;
  private int floatIx;
  private int doubleIx;
  private int objectIx;

  protected static boolean[] booleans;
  protected static byte[] bytes;
  protected static short[] shorts;
  protected static char[] chars;
  protected static int[] ints;
  protected static long[] longs;
  protected static float[] floats;
  protected static double[] doubles;
  protected static int[] objects;

  public boolean readBoolean() throws IOException {
    return booleans[booleanIx++];
  }

  public byte readByte() throws IOException {
    return bytes[byteIx++];
  }

  public int readUnsignedByte() throws IOException {
    throw new UnsupportedOperationException();
  }

  public char readChar() throws IOException {
    return chars[charIx++];
  }

  public short readShort() throws IOException {
    return shorts[shortIx++];
  }

  public int readUnsignedShort() throws IOException {
    throw new UnsupportedOperationException();
  }

  public int readInt() throws IOException {
    return ints[intIx++];
  }

  public long readLong() throws IOException {
    return longs[longIx++];
  }

  public float readFloat() throws IOException {
    return floats[floatIx++];
  }

  public double readDouble() throws IOException {
    return doubles[doubleIx++];
  }

  public int readObject() throws IOException {
    return objects[objectIx++];
  }

  public void reset() {
    booleanIx = 0;
    byteIx = 0;
    shortIx = 0;
    charIx = 0;
    intIx = 0;
    longIx = 0;
    floatIx = 0;
    doubleIx = 0;
    objectIx = 0;
  }

}
